pub fn analyze_boundary(mesh: &Mesh) -> BoundaryAnalysisExpand description
Analyze boundary topology of a mesh.
Detects all boundary loops and identifies any topology issues such as non-manifold boundary vertices or malformed boundaries.
pub fn analyze_boundary(mesh: &Mesh) -> BoundaryAnalysisAnalyze boundary topology of a mesh.
Detects all boundary loops and identifies any topology issues such as non-manifold boundary vertices or malformed boundaries.