pub fn generate_rim(
inner_mesh: &Mesh,
vertex_offset: usize,
) -> (Vec<[u32; 3]>, usize)Expand description
Generate rim faces to connect inner and outer surfaces at boundaries.
This is the simple API that generates rims for all boundary loops.
Arguments
inner_mesh- The inner surface meshvertex_offset- Offset to add to vertex indices for the outer surface (typically equal to the number of vertices in the inner mesh)
Returns
A tuple of (rim faces, total boundary edge count).